@@ -19,8 +19,9 @@ def extract_tags(handler: AcodisApiHandler, tags: list):
     for key in tags:
         try:
             dict_tags[key] = handler.xml.find('.//p/span[@class="{key}"]'.format(key=key)).text.strip()
-        except AttributeError:
+        except KeyError:
+            dict_tags[key] = None
             err = "Key '{key}' not found in dictionary".format(key=key)
-            log.error(err)
-            raise AcodisParsingError(err)
+            log.warning(err)
+            pass
     return dict_tags
